#! /usr/lib/veetest/veetest -r
(revision "B.00.00")
(date "Fri 23/Oct/1992")
(component 0 "ROOTCONTEXT"
 (name "Number Base Conversion")
 (interface
 )
 (implementation
  (locked no)
  (trigMode deg)
  (nextID 13)
  (component 0 "JUNCTION"
   (name "JCT")
   (interface
    (input 1
     (type data)
     (name "A")
     (lock name constraints)
    )
    (input 2
     (type data)
     (name "B")
     (lock name constraints)
    )
    (input 3
     (type data)
     (name "C")
     (optional yes)
    )
    (input 4
     (type data)
     (name "D")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Data")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 617 388)
     (extent 46 45)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 1 "TEXTDISPLAY"
   (name "Decimal")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (extent 78 0)
    )
    (detail
     (origin 705 248)
     (extent 190 35)
    )
    (active detail)
   )
  )
  (component 2 "TEXTDISPLAY"
   (name "Hexadecimal")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (origin 1025 288)
     (extent 110 25)
    )
    (detail
     (origin 705 348)
     (extent 210 35)
     (formatter
      (realFormat standard)
      (realSigDigits 4)
      (realRadixSpec 4)
      (integerBase hexadecimal)
     )
    )
    (active detail)
   )
  )
  (component 3 "TEXTDISPLAY"
   (name "Octal")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (origin 1025 288)
     (extent 78 25)
    )
    (detail
     (origin 705 448)
     (extent 210 35)
     (formatter
      (realFormat standard)
      (realSigDigits 4)
      (realRadixSpec 4)
      (integerBase octal)
     )
    )
    (active detail)
   )
  )
  (component 4 "TEXTDISPLAY"
   (name "Binary")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (origin 1025 288)
     (extent 78 25)
    )
    (detail
     (origin 715 558)
     (extent 210 35)
     (formatter
      (realFormat standard)
      (realSigDigits 4)
      (realRadixSpec 4)
      (integerBase binary)
     )
    )
    (active detail)
   )
  )
  (component 5 "IFTHENELSE"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Then")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "Else If")
     (lock name constraints)
    )
    (output 3
     (type data)
     (name "Else If")
     (lock name constraints)
    )
    (output 4
     (type data)
     (name "Else")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr "a==\"BINARY\"")
    (component expr "a==\"DECIMAL\"")
    (component expr "a==\"HEX\"")
   )
   (views
    (icon
     (origin 256 378)
     (extent 129 45)
    )
    (detail
     (origin 256 418)
     (extent 149 124)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 6 "ENUMCONSTANT"
   (name "convert from")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Enum")
     (lock name constraints)
    )
   )
   (implementation
    (component value Enum
     (name "convert from")
     (values
      ( "BINARY" 0)
      ( "DECIMAL" 1)
      ( "HEX" 2)
      ( "OCTAL" 3)
     )
     (datum "DECIMAL")
    )
    (component autoTrigger on)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Enum
     (name "Enum")
     (shared yes)
     (datum "DECIMAL")
    )
   )
   (views
    (icon
     (extent 118 0)
    )
    (detail
     (origin 34 353)
     (extent 192 104)
     (format buttons)
    )
    (active detail)
   )
  )
  (component 7 "CONTEXT"
   (name "HEXADECIMAL")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Seq In")
     (optional yes)
    )
    (output 1
     (type data)
     (name "X")
     (lock constraints)
     (optional yes)
    )
   )
   (implementation
    (locked no)
    (trigMode deg)
    (nextID 2)
    (component 0 "CONFIRM"
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Go")
       (lock name constraints)
      )
     )
     (implementation
     )
     (views
      (icon
       (origin 470 421)
       (extent 201 39)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (component 1 "SLIDER"
     (name "HEXADECIMAL")
     (subType "Integer_Slid")
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Int32")
       (lock name constraints)
      )
     )
     (implementation
      (component value Int32
       (name "HEXADECIMAL")
       (values range 0 100)
       (datum 67)
      )
      (component autoTrigger off)
      (component initializeAtPrerun off)
      (component initializeAtActivate off)
      (component initValue Int32
       (name "LongInt")
       (datum 0)
      )
      (component detents 1)
     )
     (views
      (icon
       (origin 540 438)
       (extent 110 25)
      )
      (detail
       (origin 465 166)
       (extent 210 228)
       (formatter
        (realFormat standard)
        (realSigDigits 4)
        (realRadixSpec 4)
        (integerBase hexadecimal)
       )
      )
      (active detail)
     )
    )
    (configuration
     (connect I1:1 D0:0)
     (connect D0:1 D1:0)
     (connect D1:1 O1:1)
    )
    (ShowOnExecPanel
     (origin 336 73)
     (extent 239 325)
     (panel
      (origin 273 352)
      (extent 235 297)
      (widget 1 detail
       (title off)
       (origin 291 362)
       (extent 210 228)
       (formatter
        (realFormat standard)
        (realSigDigits 4)
        (realRadixSpec 4)
        (integerBase hexadecimal)
       )
      )
      (widget 0 icon
       (title off)
       (origin 294 603)
       (extent 201 39)
      )
     )
    )
   )
   (views
    (icon
     (origin 455 418)
     (extent 110 25)
    )
    (detail
     (origin 447 112)
     (extent 257 397)
     (configuration
      (connect I1:1 D0:0
       (Point 449 320)
       (Point 570 418)
      )
      (connect D0:1 D1:0
       (Point 673 440)
       (Point 570 135)
      )
      (connect D1:1 O1:1
       (Point 677 280)
       (Point 701 320)
      )
     )
     (stackingOrder 0 1)
    )
    (active icon)
   )
  )
  (component 8 "CONTEXT"
   (name "OCTAL")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Seq In")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Int32")
     (lock constraints)
     (optional yes)
    )
   )
   (implementation
    (locked no)
    (trigMode deg)
    (nextID 2)
    (component 0 "CONFIRM"
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Go")
       (lock name constraints)
      )
     )
     (implementation
     )
     (views
      (icon
       (origin 425 541)
       (extent 201 39)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (component 1 "SLIDER"
     (name "OCTAL")
     (subType "Integer_Slid")
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Int32")
       (lock name constraints)
      )
     )
     (implementation
      (component value Int32
       (name "OCTAL")
       (values range 0 100)
       (datum 36)
      )
      (component autoTrigger off)
      (component initializeAtPrerun off)
      (component initializeAtActivate off)
      (component initValue Int32
       (name "LongInt")
       (datum 0)
      )
      (component detents 1)
     )
     (views
      (icon
       (origin 556 228)
       (extent 78 25)
      )
      (detail
       (origin 425 286)
       (extent 210 228)
      )
      (active detail)
     )
    )
    (configuration
     (connect I1:1 D0:0)
     (connect D0:1 D1:0)
     (connect D1:1 O1:1)
    )
    (ShowOnExecPanel
     (origin 328 75)
     (extent 244 329)
     (panel
      (origin 340 370)
      (extent 240 301)
      (widget 1 detail
       (title off)
       (origin 358 380)
       (extent 210 228)
       (formatter
        (realFormat standard)
        (realSigDigits 4)
        (realRadixSpec 4)
        (integerBase octal)
       )
      )
      (widget 0 icon
       (title off)
       (origin 360 620)
       (extent 201 39)
      )
     )
    )
   )
   (views
    (icon
     (origin 471 468)
     (extent 78 25)
    )
    (detail
     (origin 404 237)
     (extent 283 366)
     (configuration
      (connect I1:1 D0:0
       (Point 406 430)
       (Point 525 538)
      )
      (connect D0:1 D1:0
       (Point 628 560)
       (Point 530 255)
      )
      (connect D1:1 O1:1
       (Point 637 400)
       (Point 684 430)
      )
     )
     (stackingOrder 0 1)
    )
    (active icon)
   )
  )
  (component 9 "CONTEXT"
   (name "DECIMAL")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Seq In")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Int32")
     (lock constraints)
     (optional yes)
    )
   )
   (implementation
    (locked no)
    (trigMode deg)
    (nextID 2)
    (component 0 "SLIDER"
     (name "DECIMAL")
     (subType "Integer_Slid")
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Int32")
       (lock name constraints)
      )
     )
     (implementation
      (component value Int32
       (name "DECIMAL")
       (values range 0 100)
       (datum 77)
      )
      (component autoTrigger off)
      (component initializeAtPrerun off)
      (component initializeAtActivate off)
      (component initValue Int32
       (name "LongInt")
       (datum 0)
      )
      (component detents 1)
     )
     (views
      (icon
       (origin 556 228)
       (extent 78 25)
      )
      (detail
       (origin 420 286)
       (extent 210 228)
      )
      (active detail)
     )
    )
    (component 1 "CONFIRM"
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Go")
       (lock name constraints)
      )
     )
     (implementation
     )
     (views
      (icon
       (origin 245 141)
       (extent 201 39)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (configuration
     (connect D1:1 D0:0)
     (connect I1:1 D1:0)
     (connect D0:1 O1:1)
    )
    (ShowOnExecPanel
     (origin 337 74)
     (extent 234 336)
     (panel
      (origin 355 246)
      (extent 230 308)
      (widget 0 detail
       (title off)
       (origin 370 257)
       (extent 199 227)
      )
      (widget 1 icon
       (title off)
       (origin 370 501)
       (extent 201 39)
      )
     )
    )
   )
   (views
    (icon
     (origin 461 358)
     (extent 78 25)
    )
    (detail
     (origin 364 117)
     (extent 283 366)
     (configuration
      (connect D1:1 D0:0
       (Point 448 160)
       (Point 525 255)
      )
      (connect I1:1 D1:0
       (Point 366 310)
       (Point 345 138)
      )
      (connect D0:1 O1:1
       (Point 632 400)
       (Point 644 310)
      )
     )
     (stackingOrder 0 1)
    )
    (active icon)
   )
  )
  (component 10 "CONTEXT"
   (name "BINARY")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Seq In")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Int32")
     (lock constraints)
     (optional yes)
    )
   )
   (implementation
    (locked no)
    (trigMode deg)
    (nextID 2)
    (component 0 "CONFIRM"
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Go")
       (lock name constraints)
      )
     )
     (implementation
     )
     (views
      (icon
       (origin 200 141)
       (extent 201 39)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (component 1 "SLIDER"
     (name "BINARY")
     (subType "Integer_Slid")
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Int32")
       (lock name constraints)
      )
     )
     (implementation
      (component value Int32
       (name "BINARY")
       (values range 0 100)
       (datum 54)
      )
      (component autoTrigger off)
      (component initializeAtPrerun off)
      (component initializeAtActivate off)
      (component initValue Int32
       (name "LongInt")
       (datum 0)
      )
      (component detents 1)
     )
     (views
      (icon
       (origin 556 228)
       (extent 78 25)
      )
      (detail
       (origin 375 286)
       (extent 210 228)
       (formatter
        (realFormat standard)
        (realSigDigits 4)
        (realRadixSpec 4)
        (integerBase binary)
       )
      )
      (active detail)
     )
    )
    (configuration
     (connect I1:1 D0:0)
     (connect D0:1 D1:0)
     (connect D1:1 O1:1)
    )
    (ShowOnExecPanel
     (origin 329 74)
     (extent 246 325)
     (panel
      (origin 339 142)
      (extent 242 297)
      (widget 1 detail
       (title off)
       (origin 355 152)
       (extent 210 228)
       (formatter
        (realFormat standard)
        (realSigDigits 4)
        (realRadixSpec 4)
        (integerBase binary)
       )
      )
      (widget 0 icon
       (title off)
       (origin 360 391)
       (extent 201 39)
      )
     )
    )
   )
   (views
    (icon
     (origin 461 298)
     (extent 78 25)
    )
    (detail
     (origin 319 117)
     (extent 283 366)
     (configuration
      (connect I1:1 D0:0
       (Point 321 310)
       (Point 300 138)
      )
      (connect D0:1 D1:0
       (Point 403 160)
       (Point 480 255)
      )
      (connect D1:1 O1:1
       (Point 587 400)
       (Point 599 310)
      )
     )
     (stackingOrder 0 1)
    )
    (active icon)
   )
  )
  (component 11 "NOTE"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 4 5
     This example is provided as an
     illustration "as is", and Hewlett-Packard
     Company makes no warranty of any kind
     with regard to this example.
    )
   )
   (views
    (icon
     (extent 181 0)
    )
    (detail
     (origin 362 114)
     (extent 397 82)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 12 "CONTEXT"
   (name "Press For")
   (interface
    (sequence in)
    (sequence out)
   )
   (implementation
    (locked no)
    (trigMode deg)
    (nextID 3)
    (component 0 "IFTHENELSE"
     (name "!= 0")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "A")
       (optional yes)
      )
      (output 1
       (type data)
       (name "Then")
       (lock name constraints)
      )
      (output 2
       (type data)
       (name "Else")
       (lock name constraints)
      )
     )
     (implementation
      (component isLocked no)
      (component expr "a!=0")
     )
     (views
      (icon
       (origin 375 460)
       (extent 46 25)
      )
      (detail
       (origin 209 308)
       (extent 73 64)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 1 "TOGGLE"
     (name "Info About")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type control)
       (name "Reset")
       (lock name constraints)
       (optional yes)
      )
      (output 1
       (type data)
       (lock name constraints)
      )
     )
     (implementation
      (component value Int32
       (name "Info About")
       (values range 0 1)
       (datum 0)
      )
      (component autoTrigger on)
      (component initializeAtPrerun off)
      (component initializeAtActivate off)
      (component initValue Int32
       (name "LongInt")
       (datum 0)
      )
     )
     (views
      (icon
       (origin 211 453)
       (extent 114 39)
       (format button)
      )
      (detail
       (origin 320 203)
       (extent 42 54)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "CONTEXT"
     (name "Info About This Example")
     (interface
      (sequence in)
      (sequence out)
     )
     (implementation
      (locked no)
      (trigMode deg)
      (nextID 2)
      (component 0 "CONFIRM"
       (name "DONE")
       (description 7 8
        This tiny "thread" begins running when the 
        enclosing UserObject is executed.  When the user
        acknowledges the OK/DONE button, there is nothing
        left to execute, so the thread ends.  Since there
        are not other threads running, the User Object
        is completed and will exit, removing the Show on
        Execute pop-up display.
       )
       (interface
        (sequence in)
        (sequence out)
        (output 1
         (type data)
         (name "Go")
         (lock name constraints)
        )
       )
       (implementation
       )
       (views
        (icon
         (origin 411 482)
         (extent 58 37)
        )
        (detail
         (origin 156 253)
         (extent 79 34)
        )
        (terminals on)
        (active icon)
       )
      )
      (component 1 "NOTE"
       (name "NotePad")
       (description 2 8
        This notepad is displayed as a Show on Execute
        panel to present the information to the reader.
       )
       (interface
       )
       (implementation
        (component text 12 9
         PURPOSE:      To show the ability of VEE to easily handle different types of data
                       including DECIMAL, HEXADECIMAL, OCTAL, & BINARY.
         
         USER INPUT REQUIRED:  Select input number base desired.  Adjust pop-up slider to the
                       value you want converted.
         
         EXPLANATION:  The Alphanumeric Displays have the ability to display their data in 
                       whatever number format the user has selected. 
         
                       NOTE: the data when in transport is decimal but at each end (i.e. the
                       slider or the alphanumeric display) the numbers are displayed in the
                       format choosen by the user.)
        )
       )
       (views
        (icon
         (origin 400 415)
         (extent 78 25)
        )
        (detail
         (origin 25 209)
         (extent 848 437)
         (editing disabled)
        )
        (active icon)
       )
      )
      (configuration
      )
      (ShowOnExecPanel
       (origin 62 43)
       (extent 849 364)
       (panel
        (origin 28 352)
        (extent 845 336)
        (widget 1 detail
         (title off)
         (origin 35 363)
         (extent 831 259)
         (editing disabled)
        )
        (widget 0 icon
         (title off)
         (origin 406 635)
         (extent 58 37)
        )
       )
      )
     )
     (views
      (icon
       (origin 342 508)
       (extent 217 25)
      )
      (detail
       (origin 7 160)
       (extent 866 520)
       (configuration
       )
       (stackingOrder 0 1)
      )
      (active icon)
     )
    )
    (configuration
     (connect D1:1 D0:1)
     (connect D2:0 D1:1)
     (connect D0:1 D2:0)
    )
   )
   (views
    (icon
     (origin 95 158)
     (extent 110 25)
    )
    (panel
     (origin 21 117)
     (extent 319 77)
     (widget 1 icon
      (title off)
      (origin 123 130)
      (extent 114 39)
      (format button)
     )
    )
    (detail
     (origin 4 115)
     (extent 912 591)
     (configuration
      (connect D1:1 D0:1
       (Point 327 472)
       (Point 372 472)
      )
      (connect D2:0 D1:1
       (Point 450 535)
       (Point 450 550)
       (Point 190 550)
       (Point 190 472)
       (Point 208 472)
      )
      (connect D0:1 D2:0
       (Point 423 462)
       (Point 450 462)
       (Point 450 505)
      )
     )
     (stackingOrder 0 1 2)
    )
    (active panel)
    (active panel)
   )
  )
  (configuration
   (connect D10:1 D0:1)
   (connect D9:1 D0:2)
   (connect D7:1 D0:3)
   (connect D8:1 D0:4)
   (connect D0:1 D1:1)
   (connect D0:1 D2:1)
   (connect D0:1 D3:1)
   (connect D0:1 D4:1)
   (connect D6:1 D5:1)
   (connect D5:3 D7:1)
   (connect D5:4 D8:1)
   (connect D5:2 D9:1)
   (connect D5:1 D10:1)
  )
 )
 (views
  (panel
   (origin 0 62)
   (extent 984 363)
   (widget 1 detail
    (title on)
    (origin 34 335)
    (extent 190 35)
   )
   (widget 2 detail
    (title on)
    (origin 249 337)
    (extent 210 35)
    (formatter
     (realFormat standard)
     (realSigDigits 4)
     (realRadixSpec 4)
     (integerBase hexadecimal)
    )
   )
   (widget 3 detail
    (title on)
    (origin 502 337)
    (extent 210 35)
    (formatter
     (realFormat standard)
     (realSigDigits 4)
     (realRadixSpec 4)
     (integerBase octal)
    )
   )
   (widget 4 detail
    (title on)
    (origin 756 338)
    (extent 210 35)
    (formatter
     (realFormat standard)
     (realSigDigits 4)
     (realRadixSpec 4)
     (integerBase binary)
    )
   )
   (widget 11 detail
    (title on)
    (origin 574 105)
    (extent 397 82)
    (editing disabled)
   )
   (widget 12 panel
    (title on)
    (origin 15 106)
    (extent 319 77)
    (widget 1 icon
     (title off)
     (origin 117 119)
     (extent 114 39)
     (format button)
    )
   )
   (widget 6 detail
    (title on)
    (origin 362 106)
    (extent 192 104)
    (format buttons)
   )
  )
  (detail
   (origin 0 62)
   (extent 933 563)
   (configuration
    (connect D10:1 D0:1
     (Point 541 310)
     (Point 570 310)
     (Point 570 390)
     (Point 614 390)
    )
    (connect D9:1 D0:2
     (Point 541 370)
     (Point 560 370)
     (Point 560 400)
     (Point 614 400)
    )
    (connect D7:1 D0:3
     (Point 567 430)
     (Point 580 430)
     (Point 580 410)
     (Point 614 410)
    )
    (connect D8:1 D0:4
     (Point 551 480)
     (Point 590 480)
     (Point 590 420)
     (Point 614 420)
    )
    (connect D0:1 D1:1
     (Point 665 410)
     (Point 680 410)
     (Point 680 265)
     (Point 702 265)
    )
    (connect D0:1 D2:1
     (Point 665 410)
     (Point 680 410)
     (Point 680 365)
     (Point 702 365)
    )
    (connect D0:1 D3:1
     (Point 665 410)
     (Point 680 410)
     (Point 680 465)
     (Point 702 465)
    )
    (connect D0:1 D4:1
     (Point 665 410)
     (Point 680 410)
     (Point 680 575)
     (Point 712 575)
    )
    (connect D6:1 D5:1
     (Point 228 405)
     (Point 240 405)
     (Point 240 400)
     (Point 253 400)
    )
    (connect D5:3 D7:1
     (Point 387 400)
     (Point 420 400)
     (Point 420 430)
     (Point 452 430)
    )
    (connect D5:4 D8:1
     (Point 387 410)
     (Point 400 410)
     (Point 400 480)
     (Point 468 480)
    )
    (connect D5:2 D9:1
     (Point 387 390)
     (Point 410 390)
     (Point 410 370)
     (Point 458 370)
    )
    (connect D5:1 D10:1
     (Point 387 380)
     (Point 400 380)
     (Point 400 310)
     (Point 458 310)
    )
   )
   (stackingOrder 1 2 3 4 6 11 12 5 10 9
     7 8 0)
  )
  (active panel)
  (active panel)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
 )
)
